/*  @file XcmVersion.h
 *
 *  libXcm  Xorg Colour Management
 *
 *  @par Copyright:
 *            2012 (C) Kai-Uwe Behrmann
 *
 *  @brief    X Color Management library
 *  @internal
 *  @author   Kai-Uwe Behrmann <ku.b@gmx.de>
 *  @par License:
 *            MIT <http://www.opensource.org/licenses/mit-license.php>
 *  @since    2012/02/15
 */

#ifndef __XCM_VERSION_H__
#define __XCM_VERSION_H__

#define XCM_HAVE_X11 1
#define XCM_HAVE_LINUX 1

#define XCM_VERSION_MAJOR 0
#define XCM_VERSION_MINOR 5
#define XCM_VERSION_MICRO 2
#define XCM_VERSION       0.5.2
#define XCM_VERSION_NUM   (0*10000+5*100+2)
#define XCM_LIB_VERSION   0:5:0

#endif /* __XCM_VERSION_H__ */
